package cn.estsh.i3plus.pojo.andon.sqlpack;

import cn.estsh.i3plus.pojo.andon.bean.*;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.AndonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description : 安灯对象查询封装
 * @Reference :
 * @Author : silliter.yuan
 * @CreateDate : 2019-05-10 10:45
 * @Modify:
 **/
public class AndonHqlPack {
    /**
     * 封装公用查询参数
     *
     * @param bean   实体对象
     * @param hqlStr 查询语句
     * @return 封装完成的查询语句
     */
    public static DdlPackBean getStringBuilderPack(BaseBean bean, DdlPackBean hqlStr) {

        // 判断工厂代码是否为空
        if (StringUtils.isNotBlank(bean.getOrganizeCode())) {
            DdlPreparedPack.getStringEqualPack(bean.getOrganizeCode(), "organizeCode", hqlStr);
        }

        // 封装有效状态和删除状态
        DdlPreparedPack.getNumEqualPack(bean.getIsValid(), "isValid", hqlStr);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", hqlStr);

        return hqlStr;
    }

    /**
     * 按灯PLC查询条件
     *
     * @param andonPLC plc实体
     * @return
     */
    public static DdlPackBean packHqlAndonPLCInfo(AndonPLC andonPLC) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getStringEqualPack(andonPLC.getWorkCenterCode(), "workCenterCode", result);
        DdlPreparedPack.getStringEqualPack(andonPLC.getWorkCellCode(), "workCellCode", result);
        DdlPreparedPack.getStringEqualPack(andonPLC.getNodeIP(), "nodeIP", result);
        DdlPreparedPack.getStringEqualPack(andonPLC.getChannelName(), "channelName", result);
        DdlPreparedPack.getStringEqualPack(andonPLC.getTagName(), "tagName", result);
        DdlPreparedPack.getStringEqualPack(andonPLC.getTagAddress(), "tagAddress", result);
        DdlPreparedPack.getStringEqualPack(andonPLC.getTagType(), "tagType", result);
        DdlPreparedPack.getStringEqualPack(andonPLC.getAlarmCode(), "alarmCode", result);
        DdlPreparedPack.getStringEqualPack(andonPLC.getGroupNo(), "groupNo", result);

        getStringBuilderPack(andonPLC, result);
        return result;
    }

    /**
     * 按条件查询工作中心
     * @param mesWorkCenter
     * @return
     */
    public static DdlPackBean packHqlMesWorkCenter(MesWorkCenter mesWorkCenter){
        DdlPackBean result = new DdlPackBean();

        getStringBuilderPack(mesWorkCenter, result);

        return result;
    }

    /**
     * 按条件查询工作单元（工位）
     * @param mesWorkCell
     * @return
     */
    public static DdlPackBean packHqlMesWorkCell(MesWorkCell mesWorkCell){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(mesWorkCell.getWorkCenterCode(), "workCenterCode", result);
        getStringBuilderPack(mesWorkCell, result);

        return result;
    }

    /**
     * 按条件查询设备
     * @param mesEquipment
     * @return
     */
    public static DdlPackBean packHqlMesEquipment(MesEquipment mesEquipment){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(mesEquipment.getWorkCenterCode(), "workCenterCode", result);
        DdlPreparedPack.getStringEqualPack(mesEquipment.getWorkCellCode(), "workCellCode", result);
        getStringBuilderPack(mesEquipment, result);

        return result;
    }

    /**
     * 按条件查询班次
     * @param mesShift
     * @return
     */
    public static DdlPackBean packHqlMesShift(MesShift mesShift){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(mesShift.getWorkCenterCode(), "workCenterCode", result);
        getStringBuilderPack(mesShift, result);

        return result;
    }

    /**
     * 按条件查询ANDON呼叫原因
     * @param andonAlarmCause
     * @return
     */
    public static DdlPackBean packHqlAndonAlarmCause(AndonAlarmCause andonAlarmCause){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(andonAlarmCause.getAlarmCode(), "alarmCode", result);
        getStringBuilderPack(andonAlarmCause, result);

        return result;
    }

    /**
     * 按条件查询ANDON事件处理方法
     * @param andonEventMethod
     * @return
     */
    public static DdlPackBean packHqlAndonAlarmEventMethod(AndonEventMethod andonEventMethod){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(andonEventMethod.getAlarmCode(), "alarmCode", result);
        getStringBuilderPack(andonEventMethod, result);

        return result;
    }

    /**
     * 按条件查询ANDON事件原因
     * @param andonEventCause
     * @return
     */
    public static DdlPackBean packHqlAndonEventCause(AndonEventCause andonEventCause){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(andonEventCause.getAlarmCode(), "alarmCode", result);
        getStringBuilderPack(andonEventCause, result);

        return  result;
    }

    /**
     * 按条件查询按灯队列信息
     * @param andonManageQueue
     * @return
     */
    public static DdlPackBean packHqlAndonManageQueue(AndonManageQueue andonManageQueue, Object[] obj){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(andonManageQueue.getWorkCellCode(), "workCellCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageQueue.getWorkCenterCode(), "workCenterCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageQueue.getEquipmentCode(), "equipmentCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageQueue.getAlarmCode(), "alarmCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageQueue.getActionCode(), "actionCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageQueue.getAndonOrderNo(), "andonOrderNo", result);
        DdlPreparedPack.getStringEqualPack(andonManageQueue.getShiftCode(), "shiftCode", result);
        DdlPreparedPack.getInPackArray(obj, "statusCode", result);

        getStringBuilderPack(andonManageQueue, result);

        if(andonManageQueue.getCallTimeStart() != null || andonManageQueue.getCallTimeEnd() != null){
            DdlPreparedPack.timeBuilder(andonManageQueue.getCallTimeStart(), andonManageQueue.getCallTimeEnd(), "callTime", result, true);
        }

        // 根据优先级倒序，序号升序排序
        DdlPreparedPack.getOrderByPack(new Object[]{2, 1},
                new String[]{"priorityLevel", "seq"}, result);

        return result;
    }

    /**
     * 按条件查询按灯记录信息
     * @param andonManageRecord
     * @return
     */
    public static DdlPackBean packHqlAndonManageRecord(AndonManageRecord andonManageRecord, Object[] obj){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(andonManageRecord.getAndonOrderNo(), "andonOrderNo", result);
        DdlPreparedPack.getStringEqualPack(andonManageRecord.getWorkCellCode(), "workCellCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageRecord.getWorkCenterCode(), "workCenterCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageRecord.getEquipmentCode(), "equipmentCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageRecord.getAlarmCode(), "alarmCode", result);
        DdlPreparedPack.getStringEqualPack(andonManageRecord.getActionCode(), "actionCode", result);
        DdlPreparedPack.getInPackArray(obj, "statusCode", result);

        getStringBuilderPack(andonManageRecord, result);

        // 根据优先级倒序，序号升序排序
        DdlPreparedPack.getOrderByPack(new Object[]{2, 1},
                new String[]{"priorityLevel", "seq"}, result);

        return result;
    }

    /**
     * 按条件查询按灯系统配置信息
     * @param andonConfig
     * @return
     */
    public static DdlPackBean packHqlAndonConfig(AndonConfig andonConfig){
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(andonConfig.getConfigCode(), "configCode", result);

        getStringBuilderPack(andonConfig, result);

        return result;
    }

    /**
     * 通用查询条件
     * @param organizeCode
     * @return
     */
    public static DdlPackBean getAllBaseDataByNormalPro(BaseBean baseBean, String organizeCode) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(organizeCode, "organizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(baseBean.getIsValid(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_DEAL.NO.getValue(), "isDeleted", packBean);
        return packBean;
    }

    /**
     * MES区域信息查询条件封装
     * @param mesArea
     * @return
     */
    public static DdlPackBean getMesArea(MesArea mesArea, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesArea, organizeCode);
        if (StringUtils.isNotEmpty(mesArea.getAreaCode())) {
            DdlPreparedPack.getStringEqualPack(mesArea.getAreaCode(), "areaCode", packBean);
        }

        return packBean;
    }

    /**
     * MES工作中心信息查询条件封装
     * @param mesWorkCenter
     * @return
     */
    public static DdlPackBean getMesWorkCenter(MesWorkCenter mesWorkCenter, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesWorkCenter, organizeCode);
        if (StringUtils.isNotEmpty(mesWorkCenter.getWorkCenterCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkCenter.getWorkCenterCode(), "workCenterCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkCenter.getAreaCode())){
            DdlPreparedPack.getStringEqualPack(mesWorkCenter.getAreaCode(), "areaCode", packBean);
        }

        return packBean;
    }

    /**
     * MES工作单元信息查询条件封装
     * @param mesWorkCell
     * @return
     */
    public static DdlPackBean getMesWorkCell(MesWorkCell mesWorkCell, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesWorkCell, organizeCode);
        if (StringUtils.isNotEmpty(mesWorkCell.getWorkCenterCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkCell.getWorkCenterCode(), "workCenterCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkCell.getAreaCode())){
            DdlPreparedPack.getStringEqualPack(mesWorkCell.getAreaCode(), "areaCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkCell.getWorkCellCode())){
            DdlPreparedPack.getStringEqualPack(mesWorkCell.getWorkCellCode(), "workCellCode", packBean);
        }

        return packBean;
    }

    /**
     * MES设备信息查询条件封装
     * @param mesEquipment
     * @return
     */
    public static DdlPackBean getMesEquipment(MesEquipment mesEquipment, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesEquipment, organizeCode);
        if (StringUtils.isNotEmpty(mesEquipment.getWorkCellCode())){
            DdlPreparedPack.getStringEqualPack(mesEquipment.getWorkCellCode(), "workCellCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesEquipment.getEquipmentCode())){
            DdlPreparedPack.getStringEqualPack(mesEquipment.getEquipmentCode(), "equipmentCode", packBean);
        }

        return packBean;
    }

    /**
     * MES班次信息查询条件封装
     * @param shift
     * @return
     */
    public static DdlPackBean getMesShift(MesShift shift, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(shift, organizeCode);
        if (StringUtils.isNotEmpty(shift.getShiftCode())){
            DdlPreparedPack.getStringEqualPack(shift.getShiftCode(), "shiftCode", packBean);
        }
        if (StringUtils.isNotEmpty(shift.getShiftName())){
            DdlPreparedPack.getStringLikerPack(shift.getShiftName(), "shiftName", packBean);
        }
        if (StringUtils.isNotEmpty(shift.getWorkCenterCode())){
            DdlPreparedPack.getStringEqualPack(shift.getWorkCenterCode(), "workCenterCode", packBean);
        }

        return packBean;
    }

    /**
     * 通知配置信息封装
     * @param responseCfg
     * @return
     */
    public static DdlPackBean packAndonAlarmResponseCfg(AndonAlarmResponseCfg responseCfg) {
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getStringEqualPack(responseCfg.getAlarmCode(), "alarmCode", result);
        DdlPreparedPack.getStringEqualPack(responseCfg.getAndonStatus(), "andonStatus", result);
        DdlPreparedPack.getNumNOEqualPack(String.valueOf(AndonEnumUtil.ALARM_PRIORITY.FIRST.getValue()),
                "rpLevel", result);

        getStringBuilderPack(responseCfg, result);

        return result;
    }
}
